OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "No fue posible borrar %s de manera permanente",
    "Couldn't restore %s" : "No se pudo restaurar %s",
    "Deleted files" : "Archivos borrados",
    "Restore" : "Recuperar",
    "Delete" : "Borrar",
    "Delete permanently" : "Borrar permanentemente",
    "Error" : "Error",
    "restored" : "recuperado",
    "Name" : "Nombre",
    "Deleted" : "Borrado"
},
"nplurals=2; plural=(n != 1);");
